skillareas

# XMLRésuméLibrary: User Guide

skillarea | Element Reference | skills

## Name

skillareas — Group of one or more skill areas

Deprecated

## Synopsis

### Content Model

    (skillarea+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

### Important

This element is deprecated as of XML Résumé Library version 1.4.0. It should not be used.

`skillarea` elements are now allowed as direct children of `resume`, so `skillareas` is no longer necessary. `skillareas` is still allowed in this release of XML Résumé Library, but may be removed in future versions. It is recommended that you remove all `skillareas` elements from XML résumés.

The `skillareas` element contains one or more `skillarea`s.

This element is a top-level section of a résumé.

### Parents

`skillareas` may be contained in these elements: `resume`

## Examples

    <skillareas>
      <skillarea>
        <title>Aviation</title>
        <skillset>
          <title>Piloting</title>
          <skill>Biplanes</skill>
          <skill>Jumbo Jets</skill>
          <skill>Space Shuttle</skill>
        </skillset>
        <skillset>
          <title>Navigation</title>
          <skill>Map and charts</skill>
          <skill>Instruments</skill>
          <skill>Stars</skill>
        </skillset>
      </skillarea>

      <skillarea>
        <title>Cleaning</title>
        <skillset>
          <title>Tools</title>
          <skill>Rag</skill>
          <skill>Sponge</skill>
          <skill>Towel</skill>
        </skillset>
        <skillset>
          <title>Chemicals</title>
          <skill>Bleach</skill>
          <skill>Water</skill>
          <skill>Soap</skill>
        </skillset>
      </skillarea>
    </skillareas>

skillarea | Element Reference | skills